@@ -29,9 +29,13 @@ from six import with_metaclass
 
 __all__ = [
   'SimpleDictType', 'SimpleFrozenDictType', 'SimpleDictStructType',
-  'simpledict']
+  'simpledict', 'issimpledict', 'issimpledictclass',
+  'issimplefrozendict', 'issimplefrozendictclass',
+  'issimpledictstruct', 'issimpledictstructclass',
+  ]
 
 from warnings import warn
+from inspect import isclass
 import re as _re
 
 from ._common import *
@@ -328,7 +332,8 @@ def simpledict(
         frozenbase = frozenbasetype
     if frozenbase:
         frozenbase = frozenbase.type(base)
-        metaclass.frozen = metaclass(typename, (frozenbase,), {})
+        metaclass.frozen = metaclass(
+          typename + '.frozen', (frozenbase,), {})
     # ... and a simpledict struct type from the custom meta type
     if basestructtype:
         warn("Use structbase= instead of basestructtype=.",
@@ -336,7 +341,8 @@ def simpledict(
         structbase = basestructtype
     if structbase:
         structbase = structbase.type(base)
-        metaclass.struct = metaclass(typename, (structbase,), {})
+        metaclass.struct = metaclass(
+          typename + '.struct', (structbase,), {})
     # finally create the normal simpledict type from the custom meta type
     return metaclass(typename, (base,), {})
 
@@ -349,3 +355,45 @@ simpledict.structbase = SimpleDictStructType
 simpledict.KeyToAttrError = KeyToAttrError
 simpledict.KeyToAttrToKeyMismatch = KeyToAttrToKeyMismatch
 simpledict.AttrToKeyToAttrMismatch = AttrToKeyToAttrMismatch
+
+
+def issimpledict(obj):
+    """Check if `obj` is a simpledict instance.
+    """
+    return isinstance(obj, SimpleDictType)
+
+
+def issimpledictclass(cls):
+    """Check if `cls` is a simpledict class.
+    """
+    if not isclass(cls):
+        return False
+    return issubclass(cls, SimpleDictType)
+
+
+def issimplefrozendict(obj):
+    """Check if `obj` is a <simpledict class>.frozen instance.
+    """
+    return isinstance(obj, SimpleFrozenDictType)
+
+
+def issimplefrozendictclass(cls):
+    """Check if `cls` is a <simpledict class>.frozen class.
+    """
+    if not isclass(cls):
+        return False
+    return issubclass(cls, SimpleFrozenDictType)
+
+
+def issimpledictstruct(obj):
+    """Check if `obj` is a <simpledict class>.struct instance.
+    """
+    return isinstance(obj, SimpleDictStructType)
+
+
+def issimpledictstructclass(cls):
+    """Check if `cls` is a <simpledict class>.struct class.
+    """
+    if not isclass(cls):
+        return False
+    return issubclass(cls, SimpleDictStructType)
